@@ -223,6 +223,7 @@ class SwiftlyAPIClient:
         end_date: Optional[datetime.date] = None,
         days_of_week: Optional[list[int]] = None,
         exclude_dates: Optional[list[datetime.date]] = None,
+        routes: Optional[list[str]] = None,
     ) -> pd.DataFrame:
         """
         Get trip observations aka what actually happened on the ground
@@ -235,8 +236,9 @@ class SwiftlyAPIClient:
         :param days_of_week: The days of the week to return. If omitted, all days of the week are returned. Formatted
             as a list of isoweekdays, where 1 is Monday and 7 is Sunday.
         :param exclude_dates: The dates to exclude.
-        :param use_service_dates: If true, the service dates are used trips/stops which occur after mightnight will
+        :param use_service_dates: If true, the service dates are used trips/stops which occur after midnight will
             be returned with a time > 24:00.
+        :param routes: The routes to filter by. This is the route short name.
         :return: A pandas dataframe of the export.
         """
         query_params = self._build_default_query_params(
@@ -246,6 +248,9 @@ class SwiftlyAPIClient:
             exclude_dates=exclude_dates,
         )
 
+        if routes:
+            query_params["routes"] = ",".join(routes)
+
         query_params["format"] = "csv"
 
         resp = self._perform_request(
@@ -305,6 +310,8 @@ class SwiftlyAPIClient:
         end_date: Optional[datetime.date] = None,
         days_of_week: Optional[list[int]] = None,
         exclude_dates: Optional[list[datetime.date]] = None,
+        routes: Optional[list[str]] = None,
+        vehicles: Optional[list[str]] = None,
     ) -> pd.DataFrame:
         """
         Provides information about scheduled and observed arrivals and departures for specified route(s).
@@ -319,6 +326,8 @@ class SwiftlyAPIClient:
         :param days_of_week: The days of the week to return. If omitted, all days of the week are returned. Formatted
             as a list of isoweekdays, where 1 is Monday and 7 is Sunday.
         :param exclude_dates: The dates to exclude.
+        :param routes: The routes to filter by. This is the route short name.
+        :param vehicles: The vehicles to filter by. This is the vehicle id.
         :return: A pandas dataframe of the export.
         """
         query_params = self._build_default_query_params(
@@ -330,6 +339,12 @@ class SwiftlyAPIClient:
 
         query_params["format"] = "csv"
 
+        if routes:
+            query_params["routes"] = ",".join(routes)
+
+        if vehicles:
+            query_params["vehicles"] = ",".join(vehicles)
+
         try:
             resp = self._perform_request(
                 self._format_url(self.ARRIVAL_DEPARTURE_OBSERVATIONS),
@@ -342,9 +357,13 @@ class SwiftlyAPIClient:
                 in str(e)
             ):
                 return pd.DataFrame()
+            raise
 
         try:
-            df = pd.read_csv(io.StringIO(resp))
+            df = pd.read_csv(
+                io.StringIO(resp),
+                dtype={"arrival_vehicle_id": str, "departure_vehicle_id": str},
+            )
         except pd.errors.EmptyDataError:
             df = pd.DataFrame()
         return df
